Class: RuboCop::Cop::Kata::GoodMethodName
- Inherits:
-
Base
- Object
- Base
- RuboCop::Cop::Kata::GoodMethodName
- Defined in:
- lib/rubocop/cop/kata/good_method_name.rb
Constant Summary collapse
- MSG =
"`%s` needs two words: either a concept is missing, or the method belongs on the object " \ "the second word names. Say it in one word, move it, give the role a `Prefixes`/`Suffixes` " \ "word — or, if `%s` is one domain concept here, add it to `Terms`."
Instance Method Summary collapse
Instance Method Details
#on_def(node) ⇒ Object
8 |
# File 'lib/rubocop/cop/kata/good_method_name.rb', line 8 def on_def(node) = check(node, node.method_name) |
#on_defs(node) ⇒ Object
10 |
# File 'lib/rubocop/cop/kata/good_method_name.rb', line 10 def on_defs(node) = check(node, node.method_name) |